==> fiftyone_devicedetection_onpremise-4.2.2.tar.gz: fiftyone_devicedetection_onpremise-4.2.2/fiftyone_devicedetection_onpremise/device-detection-cxx/src/common-cxx/ComponentMetaData.cpp <==
/* *********************************************************************
 * This Original Work is copyright of 51 Degrees Mobile Experts Limited.
 * Copyright 2019 51 Degrees Mobile Experts Limited, 5 Charlotte Close,
 * Caversham, Reading, Berkshire, United Kingdom RG4 7BY.
 *
 * This Original Work is licensed under the European Union Public Licence (EUPL) 
 * v.1.2 and is subject to its terms as set out below.
 *
 * If a copy of the EUPL was not distributed with this file, You can obtain
 * one at https://opensource.org/licenses/EUPL-1.2.
 *
 * The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
 * amended by the European Commission) shall be deemed incompatible for
 * the purposes of the Work and the provisions of the compatibility
 * clause in Article 5 of the EUPL shall not apply.
 * 
 * If using the Work as, or as part of, a network application, by 
 * including the attribution notice(s) required under Article 5 of the EUPL
 * in the end user terms of the application under an appropriate heading, 
 * such notice(s) shall fulfill the requirements of that article.
 * ********************************************************************* */

#include "ComponentMetaData.hpp"

using namespace FiftyoneDegrees::Common;

ComponentMetaData::ComponentMetaData()
    : ComponentMetaData(
        static_cast<byte>(-1), // component id
        "invalid", // name
        0 // default profile id
    ) { }

ComponentMetaData::ComponentMetaData(ComponentMetaData *component)
	: ComponentMetaData(
		component->getComponentId(),
		component->name, 
		component->getDefaultProfileId()) { }

ComponentMetaData::ComponentMetaData(
	byte componentId,
	string name,
	uint32_t defaultProfileId) : EntityMetaData(componentId) {
	this->name = name;
	this->defaultProfileId = defaultProfileId;
}

int ComponentMetaData::getComponentIdAsInt() {
	return (int)getComponentId();
}

byte ComponentMetaData::getComponentId() {
	return getKey();
}

string ComponentMetaData::getName() {
	return this->name;
}

uint32_t ComponentMetaData::getDefaultProfileId() {
	return this->defaultProfileId;
}

==> fiftyone_devicedetection_onpremise-4.3.5.tar.gz: fiftyone_devicedetection_onpremise-4.3.5/fiftyone_devicedetection_onpremise/device-detection-cxx/src/common-cxx/ComponentMetaData.cpp <==
/* *********************************************************************
 * This Original Work is copyright of 51 Degrees Mobile Experts Limited.
 * Copyright 2019 51 Degrees Mobile Experts Limited, 5 Charlotte Close,
 * Caversham, Reading, Berkshire, United Kingdom RG4 7BY.
 *
 * This Original Work is licensed under the European Union Public Licence (EUPL) 
 * v.1.2 and is subject to its terms as set out below.
 *
 * If a copy of the EUPL was not distributed with this file, You can obtain
 * one at https://opensource.org/licenses/EUPL-1.2.
 *
 * The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
 * amended by the European Commission) shall be deemed incompatible for
 * the purposes of the Work and the provisions of the compatibility
 * clause in Article 5 of the EUPL shall not apply.
 * 
 * If using the Work as, or as part of, a network application, by 
 * including the attribution notice(s) required under Article 5 of the EUPL
 * in the end user terms of the application under an appropriate heading, 
 * such notice(s) shall fulfill the requirements of that article.
 * ********************************************************************* */

#include "ComponentMetaData.hpp"

using namespace FiftyoneDegrees::Common;

ComponentMetaData::ComponentMetaData()
    : ComponentMetaData(
        static_cast<byte>(-1), // component id
        "invalid", // name
        0 // default profile id
    ) { }

ComponentMetaData::ComponentMetaData(ComponentMetaData *component)
	: ComponentMetaData(
		component->getComponentId(),
		component->name, 
		component->getDefaultProfileId()) { }

ComponentMetaData::ComponentMetaData(
	byte componentId,
	string name,
	uint32_t defaultProfileId) : EntityMetaData(componentId) {
	this->name = name;
	this->defaultProfileId = defaultProfileId;
}

int ComponentMetaData::getComponentIdAsInt() const {
	return (int)getComponentId();
}

byte ComponentMetaData::getComponentId() const {
	return getKey();
}

string ComponentMetaData::getName() const {
	return this->name;
}

uint32_t ComponentMetaData::getDefaultProfileId() const {
	return this->defaultProfileId;
}
